==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSZoneStatusBuilder extends io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluentImpl<io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus,io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusBuilder>{
  public DNSZoneStatusBuilder() {
    this(false);
  }
  public DNSZoneStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSZoneStatus(), validationEnabled);
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSZoneStatus(), validationEnabled);
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus instance) {
    this(fluent, instance, false);
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    fluent.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    fluent.withNameServers(instance.getNameServers()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus instance) {
    this(instance,false);
  }
  public DNSZoneStatusBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withConditions(instance.getConditions()); 
    this.withGcp(instance.getGcp()); 
    this.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    this.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    this.withNameServers(instance.getNameServers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.DNSZoneStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.DNSZoneStatus build() {
    DNSZoneStatus buildable = new DNSZoneStatus(fluent.getAws(),fluent.getAzure(),fluent.getConditions(),fluent.getGcp(),fluent.getLastSyncGeneration(),fluent.getLastSyncTimestamp(),fluent.getNameServers());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneStatusBuilder that = (DNSZoneStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.6.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSZoneStatusBuilder extends DNSZoneStatusFluentImpl<DNSZoneStatusBuilder> implements VisitableBuilder<DNSZoneStatus,DNSZoneStatusBuilder>{
  public DNSZoneStatusBuilder() {
    this(false);
  }
  public DNSZoneStatusBuilder(Boolean validationEnabled) {
    this(new DNSZoneStatus(), validationEnabled);
  }
  public DNSZoneStatusBuilder(DNSZoneStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneStatusBuilder(DNSZoneStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSZoneStatus(), validationEnabled);
  }
  public DNSZoneStatusBuilder(DNSZoneStatusFluent<?> fluent,DNSZoneStatus instance) {
    this(fluent, instance, false);
  }
  public DNSZoneStatusBuilder(DNSZoneStatusFluent<?> fluent,DNSZoneStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    fluent.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    fluent.withNameServers(instance.getNameServers()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneStatusBuilder(DNSZoneStatus instance) {
    this(instance,false);
  }
  public DNSZoneStatusBuilder(DNSZoneStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withConditions(instance.getConditions()); 
    this.withGcp(instance.getGcp()); 
    this.withLastSyncGeneration(instance.getLastSyncGeneration()); 
    this.withLastSyncTimestamp(instance.getLastSyncTimestamp()); 
    this.withNameServers(instance.getNameServers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSZoneStatusFluent<?> fluent;
  Boolean validationEnabled;
  public DNSZoneStatus build() {
    DNSZoneStatus buildable = new DNSZoneStatus(fluent.getAws(),fluent.getAzure(),fluent.getConditions(),fluent.getGcp(),fluent.getLastSyncGeneration(),fluent.getLastSyncTimestamp(),fluent.getNameServers());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
